function [visWeightEst,visWeightStdErr] = ComputeVisualWeight(cueConflicts,pseEsts,pseStdErrs)
% function [visWeightEst,visWeightStdErr] = ComputeVisualWeight(cueConflicts,pseEsts,pseStdErrs)
%
% This function computes visual cue weights using the normal equation for the b1
% estimator from the simple linear regression model. The standard error is
% estimated for the b1 estimator by propagating uncertainty through the
% normal equation. Separate routines are performed to handle the cue
% conflict levels used to compute visual weights for rats and humans (i.e.,
% the function has not been generalized to handle arbitrary cue conflict levels).
%
% Equation for b1Est estimator:
% b1Est = sum( (xi - xbar)*(yi - ybar) ) / sum( (xi - xbar)^2 )
%
% Note: This function requires the MATLAB Symbolic Math Toolbox, as well
% as the "PropError.m" function written by Brad Ridder (2007) and freely
% available online at the MATLAB Central File Exchange. A slightly
% modified version of the PropError.m function is included with this tutorial
% package under the BSD guidelines.
%
% John Sheppard, 25-July-2013

% Function checks whether the cue conflict levels provided by user match
% the levels used for rat and human datasets in the paper.
if numel(cueConflicts) == 5 && min(cueConflicts == [-2 -1 0 1 2]) % for human datasets
    
    syms pseN2 pseN1 pse0 pseP1 pseP2
    
    slope = ( -2*(pseN2 - ( (pseN2 + pseN1 + pse0 + pseP1 + pseP2) / 5)) ...
        -1*(pseN1 - ( (pseN2 + pseN1 + pse0 + pseP1 + pseP2) / 5)) ...
        +1*(pseP1 - ( (pseN2 + pseN1 + pse0 + pseP1 + pseP2) / 5)) ...
        +2*(pseP2 - ( (pseN2 + pseN1 + pse0 + pseP1 + pseP2) / 5)) ) / 10;
    
    pseN2Est = pseEsts(find( cueConflicts == -2));
    pseN1Est = pseEsts(find( cueConflicts == -1));
    pse0Est =  pseEsts(find( cueConflicts == 0));
    pseP1Est = pseEsts(find( cueConflicts == 1));
    pseP2Est = pseEsts(find( cueConflicts == 2));
    
    pseN2StdErr = pseStdErrs(find( cueConflicts == -2));
    pseN1StdErr = pseStdErrs(find( cueConflicts == -1));
    pse0StdErr =  pseStdErrs(find( cueConflicts == 0));
    pseP1StdErr = pseStdErrs(find( cueConflicts == 1));
    pseP2StdErr = pseStdErrs(find( cueConflicts == 2));
    
    [slopeEst,visWeightStdErr] = PropError(slope,[pseN2 pseN1 pse0 pseP1 pseP2],[pseN2Est pseN1Est pse0Est pseP1Est pseP2Est],[pseN2StdErr pseN1StdErr pse0StdErr pseP1StdErr pseP2StdErr]);
    visWeightEst = 0.5 - slopeEst;
    
elseif numel(cueConflicts) == 3 && min(cueConflicts == [-2 0 2]) % for rat datasets
    
    syms pseN2 pse0 pseP2
    
    slope = ( -2*(pseN2 - ( (pseN2 + pse0 + pseP2) / 3)) ...
        +2*(pseP2 - ( (pseN2 + pse0 + pseP2) / 3)) ) / 8;
    
    pseN2Est = pseEsts(find( cueConflicts == -2));
    pse0Est =  pseEsts(find( cueConflicts == 0));
    pseP2Est = pseEsts(find( cueConflicts == 2));
    
    pseN2StdErr = pseStdErrs(find( cueConflicts == -2));
    pse0StdErr = pseStdErrs(find( cueConflicts == 0));
    pseP2StdErr = pseStdErrs(find( cueConflicts == 2));
    
    [slopeEst,visWeightStdErr] = PropError(slope,[pseN2 pse0 pseP2],[pseN2Est pse0Est pseP2Est],[pseN2StdErr pse0StdErr pseP2StdErr]);
    visWeightEst = 0.5 - slopeEst;
    
else
    visWeightEst = []; visWeightStdErr = [];
    warning('This function cannot analyze the set of cue conflict levels included in input data! Refer to m-file for specification of input variables.');
end

end % EOF
