function [choiceDataByRate,psychParams,psychCurve] = FitPsychometricCurve(responses,eventRates)
% function [choiceDataByRate,psychParams,psychCurve] = FitPsychometricCurve(responses,eventRates)
% 
% Description:
%
% This function fits a cumulative Gaussian psychometric curve to behavioral
% choice data using the psignifit toolbox (http://psignifit.sourceforge.net/).
% psignifit must be installed and working in Matlab in order to execute the
% function.
%
% Inputs:
%
% responses - vector of 1's and 2's indicating low-/high-rate decisions for each trial
% eventRates - vector indicating event rate (events/second) for each trial
%
% Outputs:
%
% choiceDatabyRate - nx3 array containing choice data arranged in following
%                    format for each row:
%
%                      [Event rate, # high-rate choice trials, total # responded trials]
%
% psychParams - structure containing bootstrap estimates and standard
%               errors of the fit psychometric curve.
%
%               Parameter descriptions:
%               (1) First moment of cumulative Gaussian (mu)
%               (2) Second moment of cumulative Gaussian (sigma)
%               (3) Guessing rate (gamma)
%               (4) Lapse rate (lambda)
%               (5) Point of subjective equality (PSE)*
%
% Psychometric function specification:
% f = lambda + (1-lambda-gamma)*0.5*(1+erf(1/sqrt(2)*(rate-mu)/sigma)),
% where erf = error function, rate is the event rate (events/second),
% and lambda, gamma are constrained to fall within [0, 0.1].
% 
%              * PSE is not needed to specify the psychometric function,
%                but is included for convenience.
%
% psychCurve - nx2 array containing discretized approximation of estimated
%              psychometric curve.
%
%              Column 1: Vector of event rates (events/second)
%              Column 2: Vector of choice probabilities (P(high-rate decision))
%
% Written by John Sheppard, 7-22-2011
% Last modified 23-Jul-2013 by JPS

% Set the prior distributions for psychometric function parameters
% (used by pSignifit):
% Set uniform (flat) prior expectations for slope and bias of psychometric curve.
Priors.m_or_a = 'None';
Priors.w_or_b = 'None';

% Guessing/lapse rate parameters (lambda, gamma) are constrained to [0, 0.1] with
% uniform probability on this interval.
Priors.lambda = 'Uniform(0,.1)';
Priors.gamma  = 'Uniform(0,.1)';

uniqueEventRates = unique(eventRates);

for count = 1:length(uniqueEventRates)
    
    thisEventRate = uniqueEventRates(count);
    theseResponses = responses(find(eventRates == thisEventRate));
    
    % Number of valid, responded trials with desired event rate.
    numTrials(count) = length(find( theseResponses == 1 | theseResponses == 2));
    
    % Number of such trials where the subject made a "high-rate" decision.
    numTrialsChoseHigh(count) = length(find( theseResponses == 2));
    
end

if ~isempty(count)
    choiceDataByRate = [uniqueEventRates(:), numTrialsChoseHigh(:), numTrials(:)];
else
    choiceDataByRate=[]; BootResults=[]; diagnostics=[];
    return
end

% See psignifit documentation and code for a description of BootstrapInference and Diagnostics functions.

if nargout >=2
    BootResults = BootstrapInference(choiceDataByRate, Priors, 'sigmoid', 'gauss','core', 'ab', 'nafc', 1,'cuts', [0.25 0.50 0.75]);
    diagnostics = Diagnostics(BootResults.data, BootResults.params_estimate, 'sigmoid', BootResults.sigmoid, 'core', BootResults.core, 'nafc', BootResults.nafc, 'cuts', BootResults.cuts);
    psychCurve = diagnostics.pmf;
    [pseEst,pseStdErr] = getPSE(BootResults,diagnostics);
    psychParamNames = {'firstMoment','secondMoment','guessRate','lapseRate'};
    for count = 1:4
        psychParams(count).parameter = psychParamNames{count};
        psychParams(count).est = mean(BootResults.mcestimates(:,count));
        psychParams(count).stdErr = std(BootResults.mcestimates(:,count),[],1);
    end
    psychParams(5).parameter = 'PSE';
    psychParams(5).est = pseEst;
    psychParams(5).stdErr = pseStdErr;
end

end % EOF

function [pseEst,pseStdErr] = getPSE(BootResults,diagnostics)

if ~exist('diagnostics','var')
    diagnostics = Diagnostics(BootResults.responses, BootResults.params_estimate, 'sigmoid', BootResults.sigmoid, 'core', BootResults.core, 'nafc', BootResults.nafc, 'cuts', BootResults.cuts);
end

% Assumes model is cumulative Gaussian with guess/lapse rates and 'ab' core.
% This function is performing a bootstrap analysis on all the PSE
% estimates gleaned from psignifit's Monte Carlo resampling of the
% psychometric data (which results in many estimates of the
% psychometric curve parameters).
mcEstimates = BootResults.mcestimates;
pmfData = diagnostics.pmf;
rates = pmfData(:,1); pmf = pmfData(:,2);
for jj=1:size(mcEstimates,1)
    theta = mcEstimates(jj,:);
    thisPmf = theta(4) + (1-theta(3)-theta(4)).*0.5*(1+erf(1./sqrt(2).*(rates-theta(1))./theta(2)));
    % PSE is defined as the stimulus corresponding to 50/50
    % low-/high-rate decisions.
    [junk,pseIndex] = min(abs(thisPmf - 0.5));
    pseEsts(jj) = rates(pseIndex);
end

pseEst = mean(pseEsts);
pseStdErr = std(pseEsts);

end % EOF
