% Figure 4 generating script.
% John Sheppard, July 24, 2013
% Questions? sheppard@cshl.edu

close('all');

%% Fig. 4a (humans)
% Plot of changes in visual weights between the two unmatched-reliability
% multisensory trial types across human cohort.

clear

figure(1); clf(1); hold on;

% Unique symbol identifiers assigned to each subject.
humanSymbols = {'p','o','d','^','v','>','<'};
xPositions = [1 3 6 5 2 4 7];
% These x-axis arrangements approximately re-create the positioning of
% symbols presented in the paper (x-axis is arbitrary in this figure).

faceColor = [0.8 0.8 0.8];
edgeColor = [0 0 0];

for humanCount = 1:7
    
    % NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO PSYCHOMETRIC DATA FITS.
    % (See GetPsychometricFits.m and FitPsychometricCurve.m for details on
    % computing the psychometric fits.)
    load(['../data/human' num2str(humanCount) '_psychFits.mat']);
    
    % First visWeight is from highRelAud_lowRelVis trials (trialType index 6)
    visWeightEsts(1,humanCount) = psychFits.trialTypes(6).visWeightEst;
    visWeightStdErrs(1,humanCount) = psychFits.trialTypes(6).visWeightStdErr;
    
    % Second visWeight is from lowRelAud_highRelVis trials (trialType index 7)
    visWeightEsts(2,humanCount) = psychFits.trialTypes(7).visWeightEst;
    visWeightStdErrs(2,humanCount) = psychFits.trialTypes(7).visWeightStdErr;
    
end

visWeightChangeEsts = visWeightEsts(2,:) - visWeightEsts(1,:);
visWeightChangeStdErrs = ( visWeightStdErrs(1,:).^2 + visWeightStdErrs(2,:).^2).^(1/2);
visWeightChangeConfInts = [visWeightChangeEsts-1.96*visWeightChangeStdErrs; visWeightChangeEsts+1.96*visWeightChangeStdErrs];

% Compute one-tailed p-values using a Z-statistic.
% We used a one-tailed test because we specifically expected the visual weight to
% increase, not decrease, when visual reliability increases relative to
% auditory reliability.
visWeightChangeZVals = visWeightChangeEsts ./ visWeightChangeStdErrs;
visWeightChangePVals = (1-normcdf(visWeightChangeZVals));

% Define a criterion p-value for significance.
pCriterion = 0.05;

plot([0 8],[0 0],'--k','linewidth',1);

% Plot confidence intervals.
xRanges = repmat(xPositions,2,1);
plot(xRanges,visWeightChangeConfInts,'-k','linewidth',1);

% Now plot the symbols for each subject.
for humanCount = 1:7
    
    thisSymbol = humanSymbols{humanCount};
    thisXPosition = xPositions(humanCount);
    thisVisWeightChangeEst = visWeightChangeEsts(humanCount);
    thisVisWeightChangeConfIntMax = visWeightChangeConfInts(2,humanCount);
    thisVisWeightChangePVal = visWeightChangePVals(humanCount);
    
    if strcmp(thisSymbol,'p')
        symbolSize = 12;
    else
        symbolSize = 8;
    end
    
    plot(thisXPosition,thisVisWeightChangeEst,thisSymbol,'MarkerFaceColor',faceColor,'MarkerEdgeColor',edgeColor,'MarkerSize',symbolSize);
    
    if thisVisWeightChangePVal < pCriterion
        plot(thisXPosition,thisVisWeightChangeConfIntMax + 0.15,'*k','MarkerSize',14);
    end
end

title('Humans','fontsize',20,'fontname','times');
ylabel('Change in visual cue weight','fontname','times','fontsize',20);
set(gca,'tickdir','out','box','off','xlim',[0.5 7.5],'XTick',[],'YTick',-1:0.5:1,'ylim',[-1.25 1.25],'fontsize',20,'fontname','times');

%% Fig. 4b (humans)
% Scatter plot of predicted vs observed visual weights

figure(2); clf(2); hold on;

% plot y=x line
plot([0 1],[0 1],'--k','linewidth',1.2);

% Define colors for scatterplot
colorMap = [68 102 176; 25 101 51; 0 0 0; 244 118 33]/255;

trialTypeIndexes = 5:8;

audTrialTypeIndexes = [1 2 1 2];
visTrialTypeIndexes = [3 3 4 4];

for humanCount = 1:7
    
    load(['../data/human' num2str(humanCount) '_psychFits.mat']);
    
    for trialTypeCount = 1:numel(trialTypeIndexes)
        
        trialTypeIndex = trialTypeIndexes(trialTypeCount);
        audTrialTypeIndex = audTrialTypeIndexes(trialTypeCount);
        visTrialTypeIndex = visTrialTypeIndexes(trialTypeCount);
        
        visWeightEsts(trialTypeCount,humanCount) = psychFits.trialTypes(trialTypeIndex).visWeightEst;
        visWeightStdErrs(trialTypeCount,humanCount) = psychFits.trialTypes(trialTypeIndex).visWeightStdErr;
        
        predVisWeightEsts(trialTypeCount,humanCount) = psychFits.trialTypes(trialTypeIndex).predVisWeightEst;
        predVisWeightStdErrs(trialTypeCount,humanCount) = psychFits.trialTypes(trialTypeIndex).predVisWeightStdErr;
        
        audPSEEsts(trialTypeCount,humanCount) = psychFits.trialTypes(audTrialTypeIndex).psychParams(5).est;
        audPSEStdErrs(trialTypeCount,humanCount) = psychFits.trialTypes(audTrialTypeIndex).psychParams(5).stdErr;
        
        visPSEEsts(trialTypeCount,humanCount) = psychFits.trialTypes(visTrialTypeIndex).psychParams(5).est;
        visPSEStdErrs(trialTypeCount,humanCount) = psychFits.trialTypes(visTrialTypeIndex).psychParams(5).stdErr;
        
    end
end

% First plot the confidence intervals for each trial type.
for trialTypeCount = 1:numel(trialTypeIndexes)

    thisColor = colorMap(trialTypeCount,:);
    thisVisWeightEsts = visWeightEsts(trialTypeCount,:);
    thisVisWeightStdErrs = visWeightStdErrs(trialTypeCount,:);
    
    thisVisWeightConfInts = [thisVisWeightEsts-1.96*thisVisWeightStdErrs; ...
                             thisVisWeightEsts+1.96*thisVisWeightStdErrs];
    
    thisPredVisWeightEsts = predVisWeightEsts(trialTypeCount,:);
    thisPredVisWeightStdErrs = predVisWeightStdErrs(trialTypeCount,:);
    
    thisPredVisWeightConfInts = [thisPredVisWeightEsts-1.96*thisPredVisWeightStdErrs; ...
                                 thisPredVisWeightEsts+1.96*thisPredVisWeightStdErrs];
                         
    plot(thisPredVisWeightConfInts,repmat(thisVisWeightEsts,2,1),'color',thisColor,'linewidth',1);
    plot(repmat(thisPredVisWeightEsts,2,1),thisVisWeightConfInts,'color',thisColor,'linewidth',1);
    
end

% Now plot the symbols for each subject.
for humanCount = 1:7
    
    thisSymbol = humanSymbols{humanCount};
    if strcmp(thisSymbol,'p')
        symbolSize = 12;
    else
        symbolSize = 8;
    end
    
    for trialTypeCount = 1:numel(trialTypeIndexes)
        
        trialTypeIndex = trialTypeIndexes(trialTypeCount);
        thisColor = colorMap(trialTypeCount,:);
        
        thisVisWeightEst = visWeightEsts(trialTypeCount,humanCount);
        thisPredVisWeightEst = predVisWeightEsts(trialTypeCount,humanCount);
        
        plot(thisPredVisWeightEst,thisVisWeightEst,thisSymbol,'MarkerFaceColor',thisColor,'MarkerEdgeColor',thisColor,'MarkerSize',symbolSize);
        
    end
    
end

axis equal;
set(gca,'ylim',[-0.15 1.15],'xlim',[-0.15 1.15],'XTick',0:0.2:1,'YTick',0:0.2:1,'fontsize',18,'fontname','times');
set(gca,'TickDir','out','Box','off');
title('Humans','fontname','times','FontSize',18,'fontname','times');
ylabel('Observed visual cue weight','fontname','times','FontSize',18);
xlabel('Predicted visual cue weight','fontname','times','FontSize',18);

%% Fig. 4c (humans)
% Scatter plot of visual weights vs auditory PSEs

figure(3); clf(3); hold on;

% Define colors for scatterplot
colorMap = [68 102 176; 25 101 51; 0 0 0; 244 118 33]/255;

trialTypeIndexes = 5:8;
audTrialTypeIndexes = [1 2 1 2];
visTrialTypeIndexes = [3 3 4 4];

% First plot the confidence intervals for each trial type.
for trialTypeCount = 1:numel(trialTypeIndexes)
    
    thisColor = colorMap(trialTypeCount,:);
    
    thisVisWeightEsts = visWeightEsts(trialTypeCount,:);
    thisVisWeightStdErrs = visWeightStdErrs(trialTypeCount,:);
    
    thisVisWeightConfInts = [thisVisWeightEsts-1.96*thisVisWeightStdErrs; ...
                             thisVisWeightEsts+1.96*thisVisWeightStdErrs];
    
    thisPredVisWeightEsts = predVisWeightEsts(trialTypeCount,:);
    thisPredVisWeightStdErrs = predVisWeightStdErrs(trialTypeCount,:);
    
    thisPredVisWeightConfInts = [thisPredVisWeightEsts-1.96*thisPredVisWeightStdErrs; ...
                                 thisPredVisWeightEsts+1.96*thisPredVisWeightStdErrs];
    
    thisAudPSEEsts = audPSEEsts(trialTypeCount,:);
    thisAudPSEStdErrs = audPSEStdErrs(trialTypeCount,:);
    
    thisAudPSEConfInts = [thisAudPSEEsts-1.96*thisAudPSEStdErrs; ...
                          thisAudPSEEsts+1.96*thisAudPSEStdErrs];
    
    plot(thisAudPSEConfInts,repmat(thisVisWeightEsts,2,1),'color',thisColor,'linewidth',1);
    plot(repmat(thisAudPSEEsts,2,1),thisVisWeightConfInts,'color',thisColor,'linewidth',1);
    
end

% Now plot the symbols for each subject.
for humanCount = 1:7
    
    thisSymbol = humanSymbols{humanCount};
    if strcmp(thisSymbol,'p')
        symbolSize = 12;
    else
        symbolSize = 8;
    end
    
    for trialTypeCount = 1:numel(trialTypeIndexes)
        
        thisColor = colorMap(trialTypeCount,:);
        
        thisVisWeightEst = visWeightEsts(trialTypeCount,humanCount);
        thisAudPSEEst = audPSEEsts(trialTypeCount,humanCount);
        
        plot(thisAudPSEEst,thisVisWeightEst,thisSymbol,'MarkerFaceColor',thisColor,'MarkerEdgeColor',thisColor,'MarkerSize',symbolSize);
        
    end
end

set(gca,'ylim',[-0.25 1.25],'xlim',[6.9 15.1],'XTick',7:15,'YTick',0:0.2:1,'fontsize',18,'fontname','times');
set(gca,'TickDir','out','Box','off');
title('Humans','fontname','times','FontSize',18,'fontname','times');
ylabel('Observed visual cue weight','fontname','times','FontSize',18);
xlabel('Auditory PSE','fontname','times','FontSize',18);

%% Scatter plot of visual weights vs visual PSEs (not shown in paper)

figure(4); clf(4); hold on;

% Define colors for scatterplot
colorMap = [68 102 176; 25 101 51; 0 0 0; 244 118 33]/255;

trialTypeIndexes = 5:8;
audTrialTypeIndexes = [1 2 1 2];
visTrialTypeIndexes = [3 3 4 4];

% First plot the confidence intervals for each trial type.
for trialTypeCount = 1:numel(trialTypeIndexes)
    
    thisColor = colorMap(trialTypeCount,:);
    
    thisVisWeightEsts = visWeightEsts(trialTypeCount,:);
    thisVisWeightStdErrs = visWeightStdErrs(trialTypeCount,:);
    
    thisVisWeightConfInts = [thisVisWeightEsts-1.96*thisVisWeightStdErrs; ...
                             thisVisWeightEsts+1.96*thisVisWeightStdErrs];
    
    thisPredVisWeightEsts = predVisWeightEsts(trialTypeCount,:);
    thisPredVisWeightStdErrs = predVisWeightStdErrs(trialTypeCount,:);
    
    thisPredVisWeightConfInts = [thisPredVisWeightEsts-1.96*thisPredVisWeightStdErrs; ...
                                 thisPredVisWeightEsts+1.96*thisPredVisWeightStdErrs];
    
    thisVisPSEEsts = visPSEEsts(trialTypeCount,:);
    thisVisPSEStdErrs = visPSEStdErrs(trialTypeCount,:);
    
    thisVisPSEConfInts = [thisVisPSEEsts-1.96*thisVisPSEStdErrs; ...
                          thisVisPSEEsts+1.96*thisVisPSEStdErrs];
    
    plot(thisVisPSEConfInts,repmat(thisVisWeightEsts,2,1),'color',thisColor,'linewidth',1);
    plot(repmat(thisVisPSEEsts,2,1),thisVisWeightConfInts,'color',thisColor,'linewidth',1);
    
end

% Now plot the symbols for each subject.
for humanCount = 1:7
    
    thisSymbol = humanSymbols{humanCount};
    if strcmp(thisSymbol,'p')
        symbolSize = 12;
    else
        symbolSize = 8;
    end
    
    for trialTypeCount = 1:numel(trialTypeIndexes)
        
        thisColor = colorMap(trialTypeCount,:);
        
        thisVisWeightEst = visWeightEsts(trialTypeCount,humanCount);
        thisVisPSEEst = visPSEEsts(trialTypeCount,humanCount);
        
        plot(thisVisPSEEst,thisVisWeightEst,thisSymbol,'MarkerFaceColor',thisColor,'MarkerEdgeColor',thisColor,'MarkerSize',symbolSize);
        
    end
end

set(gca,'ylim',[-0.25 1.25],'xlim',[6.9 15.1],'XTick',7:15,'YTick',0:0.2:1,'fontsize',18,'fontname','times');
set(gca,'TickDir','out','Box','off');
title('Humans','fontname','times','FontSize',18,'fontname','times');
ylabel('Observed visual cue weight','fontname','times','FontSize',18);
xlabel('Visual PSE','fontname','times','FontSize',18);

%% Fig. 4d (rats)

% Plot of changes in visual weights between the two
% multisensory trial types across rat cohort.

clear

figure(5); clf(5); hold on;

% Unique symbol identifiers assigned to each subject.
ratSymbols = {'d','o','p','s','^'};
xPositions = [5 2 4 1 3];
% These x-axis arrangements approximately re-create the positioning of
% symbols presented in the paper (x-axis is arbitrary in this figure).
faceColor = [0.8 0.8 0.8];
edgeColor = [0 0 0];

clear visWeight* predVis* *PSE*

for ratCount = 1:5
    
    % NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO PSYCHOMETRIC DATA
    % FITS.
    % (See GetPsychometricFits.m and FitPsychometricCurve.m for details on
    % computing the psychometric fits.)
    load(['../data/rat' num2str(ratCount) '_psychFits.mat']);

    % First visWeight is from highRelAud_Vis trials (trialType index 5)
    visWeightEsts(1,ratCount) = psychFits.trialTypes(5).visWeightEst;
    visWeightStdErrs(1,ratCount) = psychFits.trialTypes(5).visWeightStdErr;
    
    % Second visWeight is from lowRelAud_highRelVis trials (trialType index 4)
    visWeightEsts(2,ratCount) = psychFits.trialTypes(4).visWeightEst;
    visWeightStdErrs(2,ratCount) = psychFits.trialTypes(4).visWeightStdErr;
    
end

visWeightChangeEsts = visWeightEsts(2,:) - visWeightEsts(1,:);
visWeightChangeStdErrs = ( visWeightStdErrs(1,:).^2 + visWeightStdErrs(2,:).^2).^(1/2);
visWeightChangeConfInts = [visWeightChangeEsts-1.96*visWeightChangeStdErrs; visWeightChangeEsts+1.96*visWeightChangeStdErrs];

% Compute p-values using a Z-statistic.
% We used a one-tailed test because we specifically expected the visual weight to
% increase, not decrease, when visual reliability increases relative to
% auditory reliability.
visWeightChangeZVals = visWeightChangeEsts ./ visWeightChangeStdErrs;
visWeightChangePVals = (1-normcdf(visWeightChangeZVals));

% Define a criterion p-value for significance.
pCriterion = 0.05;

plot([0 8],[0 0],'--k','linewidth',1);

% Plot confidence intervals.
xRanges = repmat(xPositions,2,1);
plot(xRanges,visWeightChangeConfInts,'-k','linewidth',1);

% Now plot the symbols for each subject.
for ratCount = 1:5
    
    thisSymbol = ratSymbols{ratCount};
    thisXPosition = xPositions(ratCount);
    thisVisWeightChangeEst = visWeightChangeEsts(ratCount);
    thisVisWeightChangeConfIntMax = visWeightChangeConfInts(2,ratCount);
    thisVisWeightChangePVal = visWeightChangePVals(ratCount);
    
    if strcmp(thisSymbol,'p')
        symbolSize = 12;
    else
        symbolSize = 8;
    end
    
    plot(thisXPosition,thisVisWeightChangeEst,thisSymbol,'MarkerFaceColor',faceColor,'MarkerEdgeColor',edgeColor,'MarkerSize',symbolSize);
    
    if thisVisWeightChangePVal < pCriterion
        plot(thisXPosition,thisVisWeightChangeConfIntMax + 0.1,'*k','MarkerSize',14);
    end
end

title('Rats','fontsize',20,'fontname','times');
ylabel('Change in visual cue weight','fontname','times','fontsize',20);
set(gca,'tickdir','out','box','off','xlim',[0.5 5.5],'XTick',[],'YTick',-.5:0.25:.5,'ylim',[-.6 .6],'fontsize',20,'fontname','times');

%% Fig. 4e (rats)
% Scatter plot of predicted vs observed visual weights

figure(6); clf(6); hold on;

% plot y=x line
plot([0 1],[0 1],'--k','linewidth',1.2);

% Define colors for scatterplot
colorMap = [25 101 51; 0 0 0]/255;

trialTypeIndexes = [5 4];

audTrialTypeIndexes = [2 1];
visTrialTypeIndexes = [3 3];

for ratCount = 1:5
    
    load(['../data/rat' num2str(ratCount) '_psychFits.mat']);
    
    for trialTypeCount = 1:numel(trialTypeIndexes)
        
        trialTypeIndex = trialTypeIndexes(trialTypeCount);
        audTrialTypeIndex = audTrialTypeIndexes(trialTypeCount);
        visTrialTypeIndex = visTrialTypeIndexes(trialTypeCount);
        
        visWeightEsts(trialTypeCount,ratCount) = psychFits.trialTypes(trialTypeIndex).visWeightEst;
        visWeightStdErrs(trialTypeCount,ratCount) = psychFits.trialTypes(trialTypeIndex).visWeightStdErr;
        
        predVisWeightEsts(trialTypeCount,ratCount) = psychFits.trialTypes(trialTypeIndex).predVisWeightEst;
        predVisWeightStdErrs(trialTypeCount,ratCount) = psychFits.trialTypes(trialTypeIndex).predVisWeightStdErr;
        
        audPSEEsts(trialTypeCount,ratCount) = psychFits.trialTypes(audTrialTypeIndex).psychParams(5).est;
        audPSEStdErrs(trialTypeCount,ratCount) = psychFits.trialTypes(audTrialTypeIndex).psychParams(5).stdErr;
        
        visPSEEsts(trialTypeCount,ratCount) = psychFits.trialTypes(visTrialTypeIndex).psychParams(5).est;
        visPSEStdErrs(trialTypeCount,ratCount) = psychFits.trialTypes(visTrialTypeIndex).psychParams(5).stdErr;
        
    end
end

% First plot the confidence intervals for each trial type.
for trialTypeCount = 1:numel(trialTypeIndexes)

    thisColor = colorMap(trialTypeCount,:);
    thisVisWeightEsts = visWeightEsts(trialTypeCount,:);
    thisVisWeightStdErrs = visWeightStdErrs(trialTypeCount,:);
    
    thisVisWeightConfInts = [thisVisWeightEsts-1.96*thisVisWeightStdErrs; ...
                             thisVisWeightEsts+1.96*thisVisWeightStdErrs];
    
    thisPredVisWeightEsts = predVisWeightEsts(trialTypeCount,:);
    thisPredVisWeightStdErrs = predVisWeightStdErrs(trialTypeCount,:);
    
    thisPredVisWeightConfInts = [thisPredVisWeightEsts-1.96*thisPredVisWeightStdErrs; ...
                                 thisPredVisWeightEsts+1.96*thisPredVisWeightStdErrs];
                         
    plot(thisPredVisWeightConfInts,repmat(thisVisWeightEsts,2,1),'color',thisColor,'linewidth',1);
    plot(repmat(thisPredVisWeightEsts,2,1),thisVisWeightConfInts,'color',thisColor,'linewidth',1);
    
end

% Now plot the symbols for each subject.
for ratCount = 1:5
    
    thisSymbol = ratSymbols{ratCount};
    if strcmp(thisSymbol,'p')
        symbolSize = 12;
    else
        symbolSize = 8;
    end
    
    for trialTypeCount = 1:numel(trialTypeIndexes)
        
        trialTypeIndex = trialTypeIndexes(trialTypeCount);
        thisColor = colorMap(trialTypeCount,:);
        
        thisVisWeightEst = visWeightEsts(trialTypeCount,ratCount);
        thisPredVisWeightEst = predVisWeightEsts(trialTypeCount,ratCount);
        
        plot(thisPredVisWeightEst,thisVisWeightEst,thisSymbol,'MarkerFaceColor',thisColor,'MarkerEdgeColor',thisColor,'MarkerSize',symbolSize);
        
    end
    
end

axis equal;
set(gca,'ylim',[-0.05 1.05],'xlim',[-0.05 1.05],'XTick',0:0.2:1,'YTick',0:0.2:1,'fontsize',18,'fontname','times');
set(gca,'TickDir','out','Box','off');
title('Rats','fontname','times','FontSize',18,'fontname','times');
ylabel('Observed visual cue weight','fontname','times','FontSize',18);
xlabel('Predicted visual cue weight','fontname','times','FontSize',18);

%% Fig. 4f (rats)
% Scatter plot of visual weights vs auditory PSEs.

figure(7); clf(7); hold on;

% Define colors for scatterplot.
colorMap = [25 101 51; 0 0 0]/255;

trialTypeIndexes = [5 4];
audTrialTypeIndexes = [2 1];
visTrialTypeIndexes = [3 3];

% First plot the confidence intervals for each trial type.
for trialTypeCount = 1:numel(trialTypeIndexes)
    
    thisColor = colorMap(trialTypeCount,:);
    
    thisVisWeightEsts = visWeightEsts(trialTypeCount,:);
    thisVisWeightStdErrs = visWeightStdErrs(trialTypeCount,:);
    
    thisVisWeightConfInts = [thisVisWeightEsts-1.96*thisVisWeightStdErrs; ...
                             thisVisWeightEsts+1.96*thisVisWeightStdErrs];
    
    thisPredVisWeightEsts = predVisWeightEsts(trialTypeCount,:);
    thisPredVisWeightStdErrs = predVisWeightStdErrs(trialTypeCount,:);
    
    thisPredVisWeightConfInts = [thisPredVisWeightEsts-1.96*thisPredVisWeightStdErrs; ...
                                 thisPredVisWeightEsts+1.96*thisPredVisWeightStdErrs];
    
    thisAudPSEEsts = audPSEEsts(trialTypeCount,:);
    thisAudPSEStdErrs = audPSEStdErrs(trialTypeCount,:);
    
    thisAudPSEConfInts = [thisAudPSEEsts-1.96*thisAudPSEStdErrs; ...
                          thisAudPSEEsts+1.96*thisAudPSEStdErrs];
    
    plot(thisAudPSEConfInts,repmat(thisVisWeightEsts,2,1),'color',thisColor,'linewidth',1);
    plot(repmat(thisAudPSEEsts,2,1),thisVisWeightConfInts,'color',thisColor,'linewidth',1);
    
end

% Now plot the symbols for each subject.
for ratCount = 1:5
    
    thisSymbol = ratSymbols{ratCount};
    if strcmp(thisSymbol,'p')
        symbolSize = 12;
    else
        symbolSize = 8;
    end
    
    for trialTypeCount = 1:numel(trialTypeIndexes)
        
        thisColor = colorMap(trialTypeCount,:);
        
        thisVisWeightEst = visWeightEsts(trialTypeCount,ratCount);
        thisAudPSEEst = audPSEEsts(trialTypeCount,ratCount);
        
        plot(thisAudPSEEst,thisVisWeightEst,thisSymbol,'MarkerFaceColor',thisColor,'MarkerEdgeColor',thisColor,'MarkerSize',symbolSize);
        
    end
end

set(gca,'ylim',[-0 1],'xlim',[8.9 16.1],'XTick',9:16,'YTick',0:0.2:1,'fontsize',18,'fontname','times');
set(gca,'TickDir','out','Box','off');
title('Rats','fontname','times','FontSize',18,'fontname','times');
ylabel('Observed visual cue weight','fontname','times','FontSize',18);
xlabel('Auditory PSE','fontname','times','FontSize',18);

%% Scatter plot of visual weights vs visual PSEs (not shown in paper)

figure(8); clf(8); hold on;

% Define colors for scatterplot.
colorMap = [25 101 51; 0 0 0]/255;

trialTypeIndexes = [5 4];
audTrialTypeIndexes = [2 1];
visTrialTypeIndexes = [3 3];

% First plot the confidence intervals for each trial type.
for trialTypeCount = 1:numel(trialTypeIndexes)
    
    thisColor = colorMap(trialTypeCount,:);
    
    thisVisWeightEsts = visWeightEsts(trialTypeCount,:);
    thisVisWeightStdErrs = visWeightStdErrs(trialTypeCount,:);
    
    thisVisWeightConfInts = [thisVisWeightEsts-1.96*thisVisWeightStdErrs; ...
                             thisVisWeightEsts+1.96*thisVisWeightStdErrs];
    
    thisPredVisWeightEsts = predVisWeightEsts(trialTypeCount,:);
    thisPredVisWeightStdErrs = predVisWeightStdErrs(trialTypeCount,:);
    
    thisPredVisWeightConfInts = [thisPredVisWeightEsts-1.96*thisPredVisWeightStdErrs; ...
                                 thisPredVisWeightEsts+1.96*thisPredVisWeightStdErrs];
    
    thisVisPSEEsts = visPSEEsts(trialTypeCount,:);
    thisVisPSEStdErrs = visPSEStdErrs(trialTypeCount,:);
    
    thisVisPSEConfInts = [thisVisPSEEsts-1.96*thisVisPSEStdErrs; ...
                          thisVisPSEEsts+1.96*thisVisPSEStdErrs];
    
    plot(thisVisPSEConfInts,repmat(thisVisWeightEsts,2,1),'color',thisColor,'linewidth',1);
    plot(repmat(thisVisPSEEsts,2,1),thisVisWeightConfInts,'color',thisColor,'linewidth',1);
    
end

% Now plot the symbols for each subject.
for ratCount = 1:5
    
    thisSymbol = ratSymbols{ratCount};
    if strcmp(thisSymbol,'p')
        symbolSize = 12;
    else
        symbolSize = 8;
    end
    
    for trialTypeCount = 1:numel(trialTypeIndexes)
        
        thisColor = colorMap(trialTypeCount,:);
        
        thisVisWeightEst = visWeightEsts(trialTypeCount,ratCount);
        thisVisPSEEst = visPSEEsts(trialTypeCount,ratCount);
        
        plot(thisVisPSEEst,thisVisWeightEst,thisSymbol,'MarkerFaceColor',thisColor,'MarkerEdgeColor',thisColor,'MarkerSize',symbolSize);
        
    end
end

set(gca,'ylim',[-0 1],'xlim',[8.9 16.1],'XTick',9:16,'YTick',0:0.2:1,'fontsize',18,'fontname','times');
set(gca,'TickDir','out','Box','off');
title('Rats','fontname','times','FontSize',18,'fontname','times');
ylabel('Observed visual cue weight','fontname','times','FontSize',18);
xlabel('Visual PSE','fontname','times','FontSize',18);