% Figure 6 generating script.
% John Sheppard, July 24, 2013
% Questions? sheppard@cshl.edu

close('all');

%%
% The section of code below will construct pooled rat and human datasets including all the
% data across each cohort. GetPsychometricFits can then be run on the
% pooled datsets to fit psych curves, compute excess rate curves, etc.
% However, for convenience, the pooled datasets and corresponding "psychFits"
% data structures are pre-compiled in this tutorial package.

% Compile pooled raw datasets for human and rat cohorts in order to plot
% Figs. 6a-b.


%% Humans
%{
pooledDat = [];

for humanCount = 1:7
    % NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
    load(['../data/human' num2str(humanCount) '.mat']);
    pooledDat = [pooledDat, dat];
end

dat = pooledDat; clear pooledDat;

% Save pooled dataset.
save('../data/humanPooled.mat','dat');
% This pooled dataset can then be analyzed with GetPsychometricFits.m.

%% Rats

pooledDat = [];

for ratCount = 1:5
    % NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
    load(['../data/rat' num2str(ratCount) '.mat']);
    pooledDat = [pooledDat, dat];
end

dat = pooledDat; clear pooledDat;

% Save pooled dataset.
save('../data/ratPooled.mat','dat');
% This pooled dataset can subsequently be analyzed with GetPsychometricFits.m.
%}

%% Fig. 6a
% Auditory excess rate curves from composite data pooled across entire
% human cohort (n=7).

% NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
load('../data/humanPooled_psychFits.mat');

trialTypeIndexes = [1 2];

% Set colors for plots
colorMap = [69 103 176; 0 100 0]/255;

figure(1); clf(1); hold on;

for trialTypeCount = 1:numel(trialTypeIndexes)
    
    thisColor = colorMap(trialTypeCount,:);
    trialTypeIndex = trialTypeIndexes(trialTypeCount);
    timeVector = psychFits.trialTypes(trialTypeIndex).excessRateResults.timeVector;
    thisExcessRateEst = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateEsts;
    thisExcessRateStdErr = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateStdErrs;
    thisExcessRateShuffleEst = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateShuffleEsts;
    stimDuration = psychFits.trialTypes(trialTypeIndex).excessRateResults.stimDuration;
    
    % Apply a moving-average filter with a filter width of 130 ms (current
    % index + 6 indexes on either flank = 1+6+6 = 13 = 130 ms moving
    % average). This is only to smooth out artifacts from the excess rate
    % due to arrival of discrete events over the trial duration (i.e., for
    % clarity of display). It was not applied to the raw data when computing
    % statistics.
    % This uses the function movingAverage.m, authored by Carlos Adrin
    % Vargas Aguilera and freely available online at
    % http://www.mathworks.com/matlabcentral/fileexchange/12276-movingavera
    % ge-v3-1-mar-2008. A copy of this function is included with this
    % tutorial.
    thisExcessRateEst = movingAverage(thisExcessRateEst,6);
    thisExcessRateStdErr = movingAverage(thisExcessRateStdErr,6);
    thisExcessRateShuffleEst = movingAverage(thisExcessRateShuffleEst,6);
    
    % Plot the excess rate curve and bootstrapped standard error using boundedLine.m.
    % boundedLine (c) 2010-2012 Kelly Kearney, freely available on MatLAB
    % Central File Exchange. This function is included with this tutorial
    % under the BSD guidelines.
    [hl,hp]=boundedLine(timeVector,thisExcessRateEst,thisExcessRateStdErr,'cmap',thisColor);
    delete(hl);
    plot(timeVector,thisExcessRateEst,'-','color',thisColor,'linewidth',2);
    
    % Plot the excess rate "shuffle" control curve.
    plot(timeVector,thisExcessRateShuffleEst,'--','color',thisColor,'linewidth',2);
    
    xlabel('Time preceding end of stimulus (ms)','fontname','times','fontsize',22);
    ylabel('Excess rate (events/s)','fontname','times','fontsize',22);
    
    xTickLabels = -1 * fliplr(200:200:stimDuration-100);
    
    set(gca,'tickdir','out','box','off','xticklabel',xTickLabels,'xlim',[100 930],'xtick',200:200:stimDuration-100);
    set(gca,'ylim',[-1 5],'ytick',-1:5,'yticklabel',{'','0','1','2','3','4','5'},'fontname','times','fontsize',18);
    set(gcf,'paperposition',[0.25 5 8 5]);
    
end

%% Fig. 6b
% Auditory excess rate curves from composite data pooled across entire rat
% cohort (n=5).

% NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO BEHAVIORAL DATASETS.
load('../data/ratPooled_psychFits.mat');

trialTypeIndexes = [1 2];

% Set colors for plots
colorMap = [69 103 176; 0 100 0]/255;

figure(2); clf(2); hold on;

for trialTypeCount = 1:numel(trialTypeIndexes)
    
    thisColor = colorMap(trialTypeCount,:);
    trialTypeIndex = trialTypeIndexes(trialTypeCount);
    timeVector = psychFits.trialTypes(trialTypeIndex).excessRateResults.timeVector;
    thisExcessRateEst = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateEsts;
    thisExcessRateStdErr = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateStdErrs;
    thisExcessRateShuffleEst = psychFits.trialTypes(trialTypeIndex).excessRateResults.excessRateShuffleEsts;
    stimDuration = psychFits.trialTypes(trialTypeIndex).excessRateResults.stimDuration;
    
    thisExcessRateEst = movingAverage(thisExcessRateEst,6);
    thisExcessRateStdErr = movingAverage(thisExcessRateStdErr,6);
    thisExcessRateShuffleEst = movingAverage(thisExcessRateShuffleEst,6);
    
    [hl,hp]=boundedLine(timeVector,thisExcessRateEst,thisExcessRateStdErr,'cmap',thisColor);
    delete(hl);
    plot(timeVector,thisExcessRateEst,'-','color',thisColor,'linewidth',2);
    
    % Plot the excess rate "shuffle" control curve.
    plot(timeVector,thisExcessRateShuffleEst,'--','color',thisColor,'linewidth',2);
    
    xlabel('Time preceding end of stimulus (ms)','fontname','times','fontsize',22);
    ylabel('Excess rate (events/s)','fontname','times','fontsize',22);
    
    xTickLabels = -1 * fliplr(200:200:stimDuration-100);
    
    set(gca,'tickdir','out','box','off','xticklabel',xTickLabels,'xlim',[100 930],'xtick',200:200:stimDuration-100);
    set(gca,'ylim',[-.5 2],'ytick',-.5:.5:2,'yticklabel',{'','0','0.5','1','1.5','2'},'fontname','times','fontsize',18);
    set(gcf,'paperposition',[0.25 5 8 5]);
    
end

%% Fig. 6c
% Scatterplot comparing excess rate values computed within bins centered at
% -300 and -700 prior to stimulus offset.

figure(3); clf(3); hold on;

humanAudColorMap = [68,102,176; 25,105,51]./255;
humanVisColorMap = [149 151 154; 0 0 0]./255;
humanColorMap = [humanAudColorMap; humanVisColorMap];

ratAudColorMap = [68,102,176; 25,105,51]./255;
ratVisColorMap = [0 0 0; 0 0 0]./255;
ratColorMap = [ratAudColorMap; ratVisColorMap];

% These timepoints are chosen to compute the excess rate values at t = -300 and
% t = -700 before stimulus offset. For humans, the
% window center positions closest to these times fall at 296 and 696 ms. 
% For rats, the center positions of the sliding windows have timepoints 
% at 300.5 and 700.5 ms.
humanTimestamps = [296, 696];
ratTimestamps = [300.5, 700.5];

clear human*Excess* rat*Excess*

for humanCount = 1:7
    
    % NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO PSYCHOMETRIC DATA FITS.
    load(['../data/human' num2str(humanCount) '_psychFits.mat']);
    
    for trialTypeCount = 1:4

        theseExcessRateResults = psychFits.trialTypes(trialTypeCount).excessRateResults;
        
        time1Index = find(theseExcessRateResults.timeVector == humanTimestamps(1));
        time2Index = find(theseExcessRateResults.timeVector == humanTimestamps(2));
        
        thisExcessRateEsts = theseExcessRateResults.excessRateEsts;
        thisExcessRateStdErrs = theseExcessRateResults.excessRateStdErrs;

        humanTime1ExcessRateEsts(trialTypeCount,humanCount) = thisExcessRateEsts(time1Index);
        humanTime2ExcessRateEsts(trialTypeCount,humanCount) = thisExcessRateEsts(time2Index);
        
        humanTime1ExcessRateStdErrs(trialTypeCount,humanCount) = thisExcessRateStdErrs(time1Index);
        humanTime2ExcessRateStdErrs(trialTypeCount,humanCount) = thisExcessRateStdErrs(time2Index);
        
    end
end

for ratCount = 1:5
    
    % NOTE: THE LINE BELOW MUST INDICATE CORRECT PATH TO PSYCHOMETRIC DATA FITS.
    load(['../data/rat' num2str(ratCount) '_psychFits.mat']);
    
    for trialTypeCount = 1:3

        theseExcessRateResults = psychFits.trialTypes(trialTypeCount).excessRateResults;
        
        time1Index = find(theseExcessRateResults.timeVector == ratTimestamps(1));
        time2Index = find(theseExcessRateResults.timeVector == ratTimestamps(2));
        
        thisExcessRateEsts = theseExcessRateResults.excessRateEsts;
        thisExcessRateStdErrs = theseExcessRateResults.excessRateStdErrs;
        
        ratTime1ExcessRateEsts(trialTypeCount,ratCount) = thisExcessRateEsts(time1Index);
        ratTime2ExcessRateEsts(trialTypeCount,ratCount) = thisExcessRateEsts(time2Index);
     
        ratTime1ExcessRateStdErrs(trialTypeCount,ratCount) = thisExcessRateStdErrs(time1Index);
        ratTime2ExcessRateStdErrs(trialTypeCount,ratCount) = thisExcessRateStdErrs(time2Index);
        
    end
end

% Plot the results.

plot([-5 5],[-5 5],'k--','linewidth',0.5);

for trialTypeCount = 1:4
    
    thisColor = humanColorMap(trialTypeCount,:);
    
    theseTime1ExcessRateEsts = humanTime1ExcessRateEsts(trialTypeCount,:);
    theseTime1ExcessRateStdErrs = humanTime1ExcessRateStdErrs(trialTypeCount,:);
    theseTime1ExcessRateConfInts = [theseTime1ExcessRateEsts-theseTime1ExcessRateStdErrs; ...
                                    theseTime1ExcessRateEsts+theseTime1ExcessRateStdErrs];
    
    theseTime2ExcessRateEsts = humanTime2ExcessRateEsts(trialTypeCount,:);
    theseTime2ExcessRateStdErrs = humanTime2ExcessRateStdErrs(trialTypeCount,:);
    theseTime2ExcessRateConfInts = [theseTime2ExcessRateEsts-theseTime2ExcessRateStdErrs; ...
                                    theseTime2ExcessRateEsts+theseTime2ExcessRateStdErrs];
    
    plot(repmat(theseTime1ExcessRateEsts,2,1),theseTime2ExcessRateConfInts,'color',thisColor,'linewidth',.4);
    plot(theseTime1ExcessRateConfInts,repmat(theseTime2ExcessRateEsts,2,1),'color',thisColor,'linewidth',.4);
    plot(theseTime1ExcessRateEsts,theseTime2ExcessRateEsts,'o','MarkerFaceColor',thisColor,'MarkerEdgeColor',thisColor,'MarkerSize',8);
    
end

for trialTypeCount = 1:3
    
    thisColor = ratColorMap(trialTypeCount,:);
    
    theseTime1ExcessRateEsts = ratTime1ExcessRateEsts(trialTypeCount,:);
    theseTime1ExcessRateStdErrs = ratTime1ExcessRateStdErrs(trialTypeCount,:);
    theseTime1ExcessRateConfInts = [theseTime1ExcessRateEsts-theseTime1ExcessRateStdErrs; ...
                                    theseTime1ExcessRateEsts+theseTime1ExcessRateStdErrs];
    
    theseTime2ExcessRateEsts = ratTime2ExcessRateEsts(trialTypeCount,:);
    theseTime2ExcessRateStdErrs = ratTime2ExcessRateStdErrs(trialTypeCount,:);
    theseTime2ExcessRateConfInts = [theseTime2ExcessRateEsts-theseTime2ExcessRateStdErrs; ...
                                    theseTime2ExcessRateEsts+theseTime2ExcessRateStdErrs];
    
    plot(repmat(theseTime1ExcessRateEsts,2,1),theseTime2ExcessRateConfInts,'color',thisColor,'linewidth',.4);
    plot(theseTime1ExcessRateConfInts,repmat(theseTime2ExcessRateEsts,2,1),'color',thisColor,'linewidth',.4);
    plot(theseTime1ExcessRateEsts,theseTime2ExcessRateEsts,'square','MarkerFaceColor',thisColor,'MarkerEdgeColor',thisColor,'MarkerSize',8);
    
end

set(gca,'tickdir','out','fontsize',20,'fontname','times');
xlim([-1.2 5]); set(gca,'xtick',-1:5,'xticklabels',{'','0','1','2','3','4','5'});
ylim([-1.2 5]); set(gca,'ytick',-1:5,'yticklabels',{'','0','1','2','3','4','5'});

xlabel(['Excess rate_t_=_-_7_0_0_' blanks(1) '_m_s (evts/s)'],'fontname','times','fontsize',22);
ylabel(['Excess rate_t_=_-_3_0_0_' blanks(1) '_m_s (evts/s)'],'fontname','times','fontsize',22);
